pub struct LatestPublication {
pub entry_id: InventoryEntryId,
pub resource_key: String,
pub status: LatestPublicationStatus,
pub revision_id: Option<ResourceRevisionId>,
pub generation: Option<i64>,
pub diagnostic: Option<String>,
}Expand description
Outcome of one inventory entry in a publish_latest pass.
Fields
entry_id: InventoryEntryIdresource_key: Stringstatus: LatestPublicationStatusrevision_id: Option<ResourceRevisionId>generation: Option<i64>diagnostic: Option<String>Trait Implementations
Sourceimpl Clone for LatestPublication
impl Clone for LatestPublication
Sourcefn clone(&self) -> LatestPublication
fn clone(&self) -> LatestPublication
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LatestPublication
impl Debug for LatestPublication
Sourceimpl JsonSchema for LatestPublication
impl JsonSchema for LatestPublication
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for LatestPublication
impl Serialize for LatestPublication
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more