pub struct SourceAcceptance {
pub campaign_id: EvalCampaignId,
pub experiment_id: EvalExperimentId,
pub evaluated_revision_id: ResourceRevisionId,
pub committed_revision_id: ResourceRevisionId,
pub source_commit: String,
}Fields
campaign_id: EvalCampaignIdexperiment_id: EvalExperimentIdevaluated_revision_id: ResourceRevisionIdcommitted_revision_id: ResourceRevisionIdsource_commit: StringTrait Implementations
Sourceimpl Clone for SourceAcceptance
impl Clone for SourceAcceptance
Sourcefn clone(&self) -> SourceAcceptance
fn clone(&self) -> SourceAcceptance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourceAcceptance
impl Debug for SourceAcceptance
Sourceimpl<'de> Deserialize<'de> for SourceAcceptance
impl<'de> Deserialize<'de> for SourceAcceptance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SourceAcceptance
impl JsonSchema for SourceAcceptance
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SourceAcceptance
impl RefUnwindSafe for SourceAcceptance
impl Send for SourceAcceptance
impl Sync for SourceAcceptance
impl Unpin for SourceAcceptance
impl UnsafeUnpin for SourceAcceptance
impl UnwindSafe for SourceAcceptance