pub fn merge_mcp_errors(
report: &mut StartupValidationReport,
mcp_errors: Vec<ValidationError>,
)Expand description
Fold collected MCP manifest errors into report.
Appends to the existing mcp domain report when the domain-validation pass
already produced one and creates a fresh mcp domain otherwise. A no-op
when mcp_errors is empty.